It's a SoFunc.
diff --git a/doc.go b/doc.go
index 3a89de4..e706db3 100644
--- a/doc.go
+++ b/doc.go
@@ -58,7 +58,7 @@
 }
 
 // So calls the standalone So function and additionally, calls t.Error in failure scenarios.
-func (this *Assertion) So(actual interface{}, assert AssertFunc, expected ...interface{}) bool {
+func (this *Assertion) So(actual interface{}, assert SoFunc, expected ...interface{}) bool {
 	ok, result := So(actual, assert, expected...)
 	if !ok {
 		this.failed = true
@@ -86,7 +86,7 @@
 //
 // For an alternative implementation of So (that provides more flexible return options)
 // see the `So` function in the package at github.com/smartystreets/assertions/assert.
-func So(actual interface{}, assert AssertFunc, expected ...interface{}) (bool, string) {
+func So(actual interface{}, assert SoFunc, expected ...interface{}) (bool, string) {
 	if result := so(actual, assert, expected...); len(result) == 0 {
 		return true, result
 	} else {
@@ -96,14 +96,14 @@
 
 // so is like So, except that it only returns the string message, which is blank if the
 // assertion passed. Used to facilitate testing.
-func so(actual interface{}, assert AssertFunc, expected ...interface{}) string {
+func so(actual interface{}, assert SoFunc, expected ...interface{}) string {
 	return assert(actual, expected...)
 }
 
 // AssertFunc is an alias for a function with a signature that the So()
 // function can handle. Any future or custom assertions should conform to this
 // method signature. The return value should be an empty string if the AssertFunc
 // passes and a well-formed failure message if not.
-type AssertFunc func(actual interface{}, expected ...interface{}) string
+type SoFunc func(actual interface{}, expected ...interface{}) string
 
 ////////////////////////////////////////////////////////////////////////////
@@ -96,14 +96,14 @@
 }
 
-// AssertFunc is an alias for a function with a signature that the So()
+// SoFunc is an alias for a function with a signature that the So()
 // function can handle. Any future or custom assertions should conform to this
@@ -96,14 +96,14 @@
 // function can handle. Any future or custom assertions should conform to this
-// method signature. The return value should be an empty string if the AssertFunc
+// method signature. The return value should be an empty string if the SoFunc
 // passes and a well-formed failure message if not.